from setuptools import setup

setup(
    # Application name:
    name="str_rev",

    # Version number (initial):
    version="1.2.6",

    # Application author details:
    author="name surname",
    author_email="name@addr.ess",

    # Packages
    packages=["str_rev/intrevers","int_rev"],

    # Details
    url="http://pypi.python.org/pypi/MyApplication_v010/",

    #
    # license="LICENSE.txt",
    description="Useful towel-related stuff.",

    # long_description=open("README.txt").read(),

)
